searchData={"items":[{"type":"module","title":"LocalFileCacher","doc":"This package manages a local file cache. The local file cache may be used, for example, to\nensure that you have backups of files saved when making HTTP requests to API providers. The\ncached files can be used, for example, to quickly restore backups from the saved responses.\n\n> #### Warning\n>\n> This is a pre-alpha release. It works but has some rough edges, and shouldn't be considered\n> production-ready for most use cases.","ref":"LocalFileCacher.html"},{"type":"module","title":"Installation - LocalFileCacher","doc":"Add this package to your list of dependencies in `mix.exs`, then run `mix deps.get`:\n\n```elixir\n{:local_file_cacher, \"0.1.0-alpha.1\"}\n```\n\nTo configure this project, add the following to your runtime config (e.g. `config/runtime.exs`):\n\n```elixir\nconfig :local_file_cacher, base_path: System.tmp_dir(), days_to_keep_cached_files: 7\n```\n\nNow, you may call the functions directly, or create some wrapper functions:\n\n`lib/your_project/some_api.ex`\n```elixir\ndefmodule YourProject.SomeApi do\n  def save_file_to_cache(cache_subdirectory_path, file_contents) do\n    LocalFileCacher.save_file_to_cache(\n      _application_context = __MODULE__,\n      cache_subdirectory_path,\n      file_contents,\n      _filename_suffix = \"json\"\n    )\n  end\n\n  def prune_file_cache(cache_subdirectory_path),\n    do: LocalFileCacher.prune_file_cache(__MODULE__, cache_subdirectory_path)\n\n  def get_data_from_some_endpoint do\n    cache_subdirectory_path = \"some_endpoint\"\n\n    with {:ok, resp} <- Req.get(\"https://some-api.com/someEndpoint\"),\n      :ok <- save_file_to_cache(cache_subdirectory_path, resp),\n      :ok <- process_response(resp) do\n        prune_file_cache(cache_subdirectory_path)\n      end\n    end\n  end\nend\n```","ref":"LocalFileCacher.html#module-installation"},{"type":"module","title":"Project overview - LocalFileCacher","doc":"The code in this module works on specific \"application contexts\" and \"cache subdirectory paths\".\n\nThe cache directory path is determined by joining three values together:\n\n- The base directory path for the entire file cache (e.g. `\"/tmp\"`).\n  - This value can be modified in the runtime application config (i.e. in `config/runtime.exs`):\n    - `config :local_file_cacher, base_path: System.tmp_dir()`\n\n- The application context (e.g. `YourProject.SomeApi`)\n\n- The cache subdirectory path (e.g. `\"some_endpoint\"`)\n\nUsing the above examples, the cache directory path would be\n`\"/tmp/your_project/some_context/some_endpoint\"`.","ref":"LocalFileCacher.html#module-project-overview"},{"type":"module","title":"Using the file cache - LocalFileCacher","doc":"This package has functions that can be used to:\n  - Save files to the configured directory path\n  - Prune old files from the configured directory path\n\nTo prevent your local file cache from getting too large, the functions used to prune the file\ncache could be invoked automatically by any code that saves files to the cache. By pruning the\ncache at the same time as files are saved to it, this ensures that the cache size will not grow\nto an unreasonable level over time.","ref":"LocalFileCacher.html#module-using-the-file-cache"},{"type":"module","title":"Saving files to the cache - LocalFileCacher","doc":"To save a file to the cache, call `LocalFileCacher.save_file_to_cache/5` with the relevant\nparameters for the context in which you are working.","ref":"LocalFileCacher.html#module-saving-files-to-the-cache"},{"type":"module","title":"Pruning (deleting old) files from the cache - LocalFileCacher","doc":"To prune a part of the file cache, call `LocalFileCacher.prune_file_cache/2` with the relevant\nparameters for the context in which you are working.\n\nThe number of days to keep a cached file/directory can be modified in the runtime application\nconfig (i.e. in `config/runtime.exs`).\nFor example:\n  - `config :local_file_cacher, days_to_keep_cached_files: 7`","ref":"LocalFileCacher.html#module-pruning-deleting-old-files-from-the-cache"},{"type":"module","title":"Application contexts - LocalFileCacher","doc":"The `application_context` should always be an atom that represents the context of the\napplication you are working with.","ref":"LocalFileCacher.html#module-application-contexts"},{"type":"module","title":"Application context examples - LocalFileCacher","doc":"- When working in the `YourProject.SomeApi` context, the `application_context` should be\n`YourProject.SomeApi`.\n\n- When working in the `YourProject.SomeApi.SomeCategory` context, the\n`application_context` should be `YourProject.SomeApi.SomeCategory`.\n\nNote that in the examples, the application context matches the value of the key in the config\nfiles that is used to configure that same context.","ref":"LocalFileCacher.html#module-application-context-examples"},{"type":"module","title":"Cache subdirectory paths - LocalFileCacher","doc":"A `cache_subdirectory_path` represents the subdirectory path of the file cache that is being\nused for the specific type of file being cached. Use a consistent naming strategy to ensure that\nfiles for each endpoint end up in their own subdirectory.","ref":"LocalFileCacher.html#module-cache-subdirectory-paths"},{"type":"module","title":"Cache subdirectory path examples - LocalFileCacher","doc":"- SomeAPI's `someEndpoint` endpoint: The endpoint's relative URL path could be used as the\n`cache_subdirectory_path`: `\"some_endpoint\"`\n\n- SomeAPI's `someCategory/someEndpoint` endpoint: The endpoint's relative URL path could be used\nas the `cache_subdirectory_path`, e.g. `Path.join(\"some_category\", \"some_endpoint\")`.\n\n> #### Tip {: .tip}\n>\n> For URLs that are more than one layer deep, use `Path.join/1` to ensure that the path is\n> rendered correctly on all operating systems.","ref":"LocalFileCacher.html#module-cache-subdirectory-path-examples"},{"type":"module","title":"Cache subdirectory path style guide - LocalFileCacher","doc":"- Use lowercase letters for all file paths. For example, in an endpoint called \"Endpoint\",\nprefer a cache subdirectory name of `\"endpoint\"` instead of `\"Endpoint\"`.\n\n- Separate multiple words with an underscore. For example, in an endpoint called \"Some other\nendpoint\", the cache subdirectory path should be called `\"some_other_endpoint\"`.\n\n- To ensure that path names are rendered correctly on all operating systems, use\n`Path.join/1` if the cache subdirectory path is more than one layer deep. For example, for\nan endpoint located at `\"https://some-api.com/v1/someCategory/someEndpoint\"`, prefer a cache\nsubdirectory path of `Path.join([\"v1\", \"some_category\", \"some_endpoint\"])` instead of\n`\"v1/someCategory/someEndpoint\"`.","ref":"LocalFileCacher.html#module-cache-subdirectory-path-style-guide"},{"type":"function","title":"LocalFileCacher.generate_filename_friendly_timestamp/0","doc":"Generate a timestamp-esque string that conforms to the [Portable Filename Character\nSet](https://www.ibm.com/docs/en/zvm/7.2?topic=files-naming), making it safe and convenient to\nuse as the name of a cached file or directory.","ref":"LocalFileCacher.html#generate_filename_friendly_timestamp/0"},{"type":"function","title":"Examples - LocalFileCacher.generate_filename_friendly_timestamp/0","doc":"iex> YourProject.Services.FileCache.generate_filename_friendly_timestamp()\n    \"2024-05-17-15-49-14-091430\"","ref":"LocalFileCacher.html#generate_filename_friendly_timestamp/0-examples"},{"type":"function","title":"LocalFileCacher.get_cutoff_timestamp/0","doc":"Return a UNIX timestamp that can be used to indicate whether or not a cached file can be\npruned (deleted). If the modification timestamp of a file is older than the cutoff timestamp,\nthen it can be pruned.","ref":"LocalFileCacher.html#get_cutoff_timestamp/0"},{"type":"function","title":"Examples - LocalFileCacher.get_cutoff_timestamp/0","doc":"iex> YourProject.Services.FileCache.get_cutoff_timestamp()\n    1715978870","ref":"LocalFileCacher.html#get_cutoff_timestamp/0-examples"},{"type":"function","title":"LocalFileCacher.get_file_cache_directory_path/2","doc":"Return the file cache directory path for a given `application_context` and\n`cache_subdirectory_path`.","ref":"LocalFileCacher.html#get_file_cache_directory_path/2"},{"type":"function","title":"Examples - LocalFileCacher.get_file_cache_directory_path/2","doc":"iex> YourProject.Services.FileCache.get_file_cache_directory_path(\n    ...>   YourProject.SomeApi,\n    ...>   \"some_endpoint\"\n    ...> )\n    \"/tmp/your_project/some_api/some_endpoint\"","ref":"LocalFileCacher.html#get_file_cache_directory_path/2-examples"},{"type":"function","title":"LocalFileCacher.prune_file_cache/2","doc":"Prune cached files/directories from a given `application_context` and `cache_subdirectory_path`.\n\n> #### Note {: .info}\n>\n> This function is intended to be used to build wrapper functions for your specific contexts,\n> e.g. `YourProject.SomeApi.prune_file_cache()`.","ref":"LocalFileCacher.html#prune_file_cache/2"},{"type":"function","title":"Examples - LocalFileCacher.prune_file_cache/2","doc":"Prune cached files saved from SomeAPI's `someEndpoint` endpoint:\n\n    iex> YourProject.Services.FileCache.prune_file_cache(YourProject.SomeApi, \"some_endpoint\")\n    :ok\n\nPrune cached directories/files saved from SomeAPI's `someCategory/someEndpoint` endpoint:\n\n    iex> YourProject.Services.FileCache.prune_file_cache(\n    ...>   _application_context = YourProject.SomeApi,\n    ...>   _cache_subdirectory_path = Path.join([\"some_category, \"some_endpoint\"])\n    ...> )\n    :ok\n\nPrune cached directories/files saved from some API's \"someEndpoint\" endpoint:\n\n    iex> LocalFileCacher.prune_file_cache(YourProject.SomeApi, \"some_endpoint\")\n    :ok","ref":"LocalFileCacher.html#prune_file_cache/2-examples"},{"type":"function","title":"LocalFileCacher.save_file_to_cache/5","doc":"Save `file_contents` to a given `application_context` and `cache_subdirectory_path` with a given\n`filename_suffix` (e.g. `\"json\"`, `\"txt\"`, `\"xml\"`) and optional `filename_prefix` (i.e. the\npart of the filename before the dot).\n\nIf `filename_prefix` is `nil`, then a timestamp-esque file prefix will be generated via\n`generate_filename_friendly_timestamp/0`.\n\n> #### Note {: .info}\n>\n> This function is used to build wrapper functions for specific contexts, e.g.\n> `YourProject.SomeApi.save_file_to_cache()`. You probably shouldn't call this\n> function directly. Instead, implement the `save_file_to_cache/2` callback for the context you\n> are working in.","ref":"LocalFileCacher.html#save_file_to_cache/5"},{"type":"function","title":"Examples - LocalFileCacher.save_file_to_cache/5","doc":"Save a SomeAPI `someEndpoint` response to the `\"some_endpoint\"` cache subdirectory:\n\n    iex> {:ok, resp_body} = YourProject.SomeApi.get_some_endpoint()\n\n    iex> YourProject.Services.FileCache.save_file_to_cache(\n    ...>   YourProject.SomeApi,\n    ...>   \"some_endpoint\",\n    ...>   resp_body,\n    ...>   \"json\",\n    ...> )\n    :ok\n\nSave a SomeAPI `someCategory/someEndpoint` response to the `\"some_category/some_endpoint\"` cache\nsubdirectory with a custom `filename_prefix`:\n\n    iex> {:ok, resp_body} = YourProject.SomeApi.SomeCategory.get_some_endpoint()\n\n    iex> YourProject.Services.FileCache.save_file_to_cache(\n    ...>   YourProject.SomeApi,\n    ...>   Path.join([\"some_category\", \"some_endpoint\"])\n    ...>   resp_body,\n    ...>   \"json\",\n    ...>   \"offset-000000\"\n    ...> )\n    :ok","ref":"LocalFileCacher.html#save_file_to_cache/5-examples"},{"type":"extras","title":"LocalFileCacher","doc":"# LocalFileCacher\n\nThis package manages a local file cache. The local file cache may be used, for example, to ensure\nthat you have backups of files saved when making HTTP requests to API providers. The cached files\ncan be used, for example, to quickly restore backups from the saved responses.\n\nThis package also allows old cached files to be pruned easily.\n\n> #### Warning\n>\n> This is a pre-alpha release. It works but has some rough edges, and shouldn't be considered\n> production-ready for most use cases.","ref":"readme.html"},{"type":"extras","title":"Installation - LocalFileCacher","doc":"Add this package to `mix.exs`, then run `mix deps.get`:\n\n```elixir\n{:local_file_cacher, \"0.1.0-alpha.1\"},\n```\n\nTo configure this project, add the following to your runtime config (e.g. `config/runtime.exs`):\n\n```elixir\nconfig :local_file_cacher,\n  base_path: System.tmp_dir(),\n  days_to_keep_cached_files: 7\n```\n\nNow, you may call the functions directly, or create some wrapper functions:\n\n`lib/your_project/some_api.ex`\n```elixir\ndefmodule YourProject.SomeApi do\n  def save_file_to_cache(cache_subdirectory_path, file_contents) do\n    LocalFileCacher.save_file_to_cache(\n      _application_context = __MODULE__,\n      cache_subdirectory_path,\n      file_contents,\n      _filename_suffix = \"json\"\n    )\n  end\n\n  def prune_file_cache(cache_subdirectory_path),\n    do: LocalFileCacher.prune_file_cache(__MODULE__, cache_subdirectory_path)\n\n  def get_data_from_some_endpoint do\n    cache_subdirectory_path = \"some_endpoint\"\n\n    with {:ok, resp} <- Req.get(\"https://some-api.com/someEndpoint\"),\n      :ok <- save_file_to_cache(cache_subdirectory_path, resp),\n      :ok <- process_response(resp) do\n        prune_file_cache(cache_subdirectory_path)\n      end\n    end\n  end\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Project overview - LocalFileCacher","doc":"The code in this module works on specific \"application contexts\" and \"cache subdirectory paths\".\n\nThe cache directory path is determined by joining three values together:\n\n- The base directory path for the entire file cache (e.g. `\"/tmp\"`).\n  - This value can be modified in the runtime application config (i.e. in `config/runtime.exs`):\n    - `config :local_file_cacher, base_path: System.tmp_dir()`\n\n- The application context (e.g. `YourProject.SomeApi`)\n\n- The cache subdirectory path (e.g. `\"some_endpoint\"`)\n\nUsing the above examples, the cache directory path would be\n`\"/tmp/your_project/some_context/some_endpoint\"`.\n\n---\n\nFor more information, see [the module documentation](https://hexdocs.pm/local_file_cacher/LocalFileCacher.html).\n\n---\n\nThis project made possible by Interline Travel and Tour Inc.\n\nhttps://www.perx.com/\n\nhttps://www.touchdown.co.uk/\n\nhttps://www.touchdownfrance.com/","ref":"readme.html#project-overview"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}